Struct plane_split::Plane [] [src]

pub struct Plane<T, U> {
    pub normal: TypedVector3D<T, U>,
    pub offset: T,
}

An infinite plane in 3D space, defined by equation: dot(v, normal) + offset = 0 When used for plane splitting, it's defining a hemisphere with equation "dot(v, normal) + offset > 0".

Fields

Normalized vector perpendicular to the plane.

Constant offset from the normal plane, specified in the direction opposite to the normal.

Methods

impl<T: Copy + Zero + One + Float + ApproxEq<T> + Sub<T, Output = T> + Add<T, Output = T> + Mul<T, Output = T> + Div<T, Output = T>, U> Plane<T, U>
[src]

[src]

Check if this plane contains another one.

[src]

Return the signed distance from this plane to a point. The distance is negative if the point is on the other side of the plane from the direction of the normal.

[src]

Compute the distance across the line to the plane plane, starting from the line origin.

[src]

Compute the sum of signed distances to each of the points of another plane. Useful to know the relation of a plane that is a product of a split, and we know it doesn't intersect self.

[src]

Check if a convex shape defined by a set of points is completely outside of this plane. Merely touching the surface is not considered an intersection.

[src]

Compute the line of intersection with another plane.