Struct plane_split::Clipper
[−]
[src]
pub struct Clipper<T, U> { /* fields omitted */ }A helper object to clip polygons by a number of planes.
Methods
impl<T: Copy + Debug + ApproxEq<T> + Sub<T, Output = T> + Add<T, Output = T> + Mul<T, Output = T> + Div<T, Output = T> + Zero + One + Float, U: Debug> Clipper<T, U>[src]
pub fn new() -> Self[src]
Create a new clipper object.
pub fn add(&mut self, plane: Plane<T, U>)[src]
Add a clipping plane to the list. The plane will clip everything behind it, where the direction is set by the plane normal.
pub fn clip(&mut self, polygon: Polygon<T, U>) -> &[Polygon<T, U>][src]
Clip specified polygon by the contained planes, return the fragmented polygons.